@@ -52,11 +52,11 @@
 //! let output = r#".TH roffman 7 "August 2021"
 //! .SH "BASIC USAGE"
 //! .P
-//! This is how you create a basic paragraph using roffman\.
+//! This is how you create a basic paragraph using roffman.
 //! .IP optional\-title 4
-//! This line should be slightly indented to the \fBright\.\fR
+//! This line should be slightly indented to the \fBright.\fR
 //! .SY roffman\-command
-//! This is the description of this command\. It will be displayed right next to\fI it\fR
+//! This is the description of this command. It will be displayed right next to\fI it\fR
 //!
 //! .OP \-\-opt
 //! some simple opt
@@ -73,11 +73,11 @@
 //!
 //! impl Roffable for u8 {
 //!     fn roff(&self) \-> RoffText {
-//!         self\.to_string()\.roff()
+//!         self.to_string().roff()
 //!     }
 //! }
 //! .EE
-//! .UR https://github\.com/vv9k/roffman
+//! .UR https://github.com/vv9k/roffman
 //! GitHub
 //! .UE
 //!
@@ -117,39 +117,57 @@
 //!                                                               August 2021                                             roffman(7)
 //! ```
 
+mod escape;
+mod node;
+mod section;
+mod text;
+
+pub use node::RoffNode;
+pub use section::Section;
+pub use text::{FontStyle, RoffText};
+
+use escape::escape;
+
 use std::error::Error;
 use std::fmt;
 use std::fmt::Formatter;
 use std::io::{self, Write};
 
-const SPACE: &[u8] = b" ";
-const QUOTE: &[u8] = b"\"";
-const ENDL: &[u8] = b"\n";
-const BOLD: &[u8] = b"\\fB";
-const ITALIC: &[u8] = b"\\fI";
-const FONT_END: &[u8] = b"\\fR";
-const SECTION_HEADER: &[u8] = b".SH";
-const SUB_HEADER: &[u8] = b".SS";
-const TITLE_HEADER: &[u8] = b".TH";
-const PARAGRAPH: &[u8] = b".P";
-const INDENTED_PARAGRAPH: &[u8] = b".IP";
-const TAGGED_PARAGRAPH: &[u8] = b".TP";
-const NESTED_START: &[u8] = b".RS";
-const NESTED_END: &[u8] = b".RE";
-const EXAMPLE_START: &[u8] = b".EX";
-const EXAMPLE_END: &[u8] = b".EE";
-const SYNOPSIS_START: &[u8] = b".SY";
-const SYNOPSIS_END: &[u8] = b".YS";
-const SYNOPSIS_OPT: &[u8] = b".OP";
-const URL_START: &[u8] = b".UR";
-const URL_END: &[u8] = b".UE";
-const MAIL_START: &[u8] = b".MT";
-const MAIL_END: &[u8] = b".ME";
-const LEFT_QUOTE: &[u8] = b"\\*(lq";
-const RIGHT_QUOTE: &[u8] = b"\\*(rq";
-const REGISTERED_SIGN: &[u8] = b"\\*R";
-const TRADEMARK_SIGN: &[u8] = b"\\*(Tm";
-const BREAK: &[u8] = b".br";
+mod _macro {
+    pub(crate) const SPACE: &[u8] = b" ";
+    pub(crate) const QUOTE: &[u8] = b"\"";
+    pub(crate) const ENDL: &[u8] = b"\n";
+    pub(crate) const BOLD: &[u8] = b"\\fB";
+    pub(crate) const ITALIC: &[u8] = b"\\fI";
+    pub(crate) const FONT_END: &[u8] = b"\\fR";
+    pub(crate) const SECTION_HEADER: &[u8] = b".SH";
+    pub(crate) const SUB_HEADER: &[u8] = b".SS";
+    pub(crate) const TITLE_HEADER: &[u8] = b".TH";
+    pub(crate) const PARAGRAPH: &[u8] = b".P";
+    pub(crate) const INDENTED_PARAGRAPH: &[u8] = b".IP";
+    pub(crate) const TAGGED_PARAGRAPH: &[u8] = b".TP";
+    pub(crate) const NESTED_START: &[u8] = b".RS";
+    pub(crate) const NESTED_END: &[u8] = b".RE";
+    pub(crate) const EXAMPLE_START: &[u8] = b".EX";
+    pub(crate) const EXAMPLE_END: &[u8] = b".EE";
+    pub(crate) const SYNOPSIS_START: &[u8] = b".SY";
+    pub(crate) const SYNOPSIS_END: &[u8] = b".YS";
+    pub(crate) const SYNOPSIS_OPT: &[u8] = b".OP";
+    pub(crate) const URL_START: &[u8] = b".UR";
+    pub(crate) const URL_END: &[u8] = b".UE";
+    pub(crate) const MAIL_START: &[u8] = b".MT";
+    pub(crate) const MAIL_END: &[u8] = b".ME";
+    pub(crate) const LEFT_QUOTE: &[u8] = b"\\(lq";
+    pub(crate) const RIGHT_QUOTE: &[u8] = b"\\(rq";
+    pub(crate) const REGISTERED_SIGN: &[u8] = b"\\(rg";
+    pub(crate) const TRADEMARK_SIGN: &[u8] = b"\\(tm";
+    pub(crate) const BREAK: &[u8] = b".br";
+    pub(crate) const EM_DASH: &[u8] = b"\\(em";
+    pub(crate) const EN_DASH: &[u8] = b"\\(en";
+    pub(crate) const NON_BREAKING_SPACE: &[u8] = b"\\~";
+    pub(crate) const COMMENT: &[u8] = b"\\\"";
+}
+use _macro::{ENDL, QUOTE, SPACE, TITLE_HEADER};
 
 #[derive(Debug)]
 /// An error type returned by the functions used in this crate.
@@ -184,12 +202,6 @@ impl From<io::Error> for RoffError {
     }
 }
 
-fn escape<T: AsRef<str>>(text: T) -> String {
-    let text = text.as_ref();
-    let text = text.replace('.', "\\.");
-    text.replace('-', "\\-")
-}
-
 fn write_quoted(roff: &RoffText, writer: &mut impl Write) -> Result<(), RoffError> {
     writer.write_all(QUOTE)?;
     roff.render(writer)?;
@@ -198,7 +210,12 @@ fn write_quoted(roff: &RoffText, writer: &mut impl Write) -> Result<(), RoffErro
 }
 
 fn write_quoted_if_whitespace(roff: &RoffText, writer: &mut impl Write) -> Result<(), RoffError> {
-    if roff.content.as_bytes().iter().any(u8::is_ascii_whitespace) {
+    if roff
+        .content()
+        .as_bytes()
+        .iter()
+        .any(u8::is_ascii_whitespace)
+    {
         write_quoted(roff, writer)
     } else {
         roff.render(writer)
@@ -348,274 +365,6 @@ impl Roffable for SectionNumber {
     }
 }
 
-#[derive(Clone, Debug)]
-/// A single section of the ROFF document.
-pub struct Section {
-    title: RoffText,
-    subtitle: Option<RoffText>,
-    nodes: Vec<RoffNodeInner>,
-}
-
-impl Section {
-    /// Create a new section with `title` and `content`.
-    pub fn new<I, R>(title: impl Roffable, content: I) -> Self
-    where
-        I: IntoIterator<Item = R>,
-        R: IntoRoffNode,
-    {
-        Self {
-            title: title.roff(),
-            subtitle: None,
-            nodes: content
-                .into_iter()
-                .map(|r| r.into_roff().into_inner())
-                .collect(),
-        }
-    }
-
-    /// Set the sub heading of this section.
-    pub fn subtitle(mut self, subtitle: impl Roffable) -> Self {
-        self.subtitle = Some(subtitle.roff());
-        self
-    }
-
-    fn render<W: Write>(&self, writer: &mut W, was_text: bool) -> Result<bool, RoffError> {
-        if was_text {
-            writer.write_all(ENDL)?;
-        }
-        writer.write_all(SECTION_HEADER)?;
-        writer.write_all(SPACE)?;
-        write_quoted_if_whitespace(&self.title, writer)?;
-        writer.write_all(ENDL)?;
-        if let Some(subtitle) = &self.subtitle {
-            writer.write_all(SUB_HEADER)?;
-            writer.write_all(SPACE)?;
-            write_quoted_if_whitespace(subtitle, writer)?;
-            writer.write_all(ENDL)?;
-        }
-
-        let mut was_text = false;
-        for node in &self.nodes {
-            was_text = node.render(writer, was_text)?;
-        }
-
-        Ok(was_text)
-    }
-}
-
-#[derive(Copy, Clone, Debug, PartialEq)]
-/// Style that can be applied to [`RoffText`](RoffText)
-pub enum FontStyle {
-    Bold,
-    Italic,
-    Roman,
-}
-
-impl Default for FontStyle {
-    fn default() -> Self {
-        FontStyle::Roman
-    }
-}
-
-#[derive(Clone, Debug, Default, PartialEq)]
-/// Wrapper type for styled text in ROFF.
-pub struct RoffText {
-    content: String,
-    style: FontStyle,
-}
-
-impl RoffText {
-    pub fn new<C: AsRef<str>>(content: C, style: Option<FontStyle>) -> Self {
-        Self {
-            content: escape(content),
-            style: style.unwrap_or_default(),
-        }
-    }
-
-    /// Set the style of this text to bold.
-    pub fn bold(mut self) -> Self {
-        self.style = FontStyle::Bold;
-        self
-    }
-
-    /// Set the style of this text to italic.
-    pub fn italic(mut self) -> Self {
-        self.style = FontStyle::Italic;
-        self
-    }
-
-    fn render<W: Write>(&self, writer: &mut W) -> Result<(), RoffError> {
-        let styled = match self.style {
-            FontStyle::Bold => {
-                writer.write_all(BOLD)?;
-                true
-            }
-            FontStyle::Italic => {
-                writer.write_all(ITALIC)?;
-                true
-            }
-            FontStyle::Roman => false,
-        };
-
-        writer.write_all(self.content.as_bytes())?;
-        if styled {
-            writer.write_all(FONT_END)?;
-        }
-
-        Ok(())
-    }
-}
-
-#[derive(Clone, Debug)]
-/// Base struct used to create ROFFs.
-pub struct RoffNode(RoffNodeInner);
-
-impl RoffNode {
-    #[inline]
-    fn into_inner(self) -> RoffNodeInner {
-        self.0
-    }
-
-    #[inline]
-    fn inner_ref(&self) -> &RoffNodeInner {
-        &self.0
-    }
-
-    /// Creates a simple text node.
-    pub fn text(content: impl Roffable) -> Self {
-        Self(RoffNodeInner::Text(content.roff()))
-    }
-
-    /// Creates a new paragraph node.
-    pub fn paragraph<I, R>(content: I) -> Self
-    where
-        I: IntoIterator<Item = R>,
-        R: IntoRoffNode,
-    {
-        Self(RoffNodeInner::Paragraph(
-            content
-                .into_iter()
-                .map(|item| item.into_roff().into_inner())
-                .collect(),
-        ))
-    }
-
-    /// Creates a new indented paragraph node.
-    pub fn indented_paragraph<I, R>(
-        content: I,
-        indentation: Option<u8>,
-        title: Option<impl Roffable>,
-    ) -> Self
-    where
-        I: IntoIterator<Item = R>,
-        R: IntoRoffNode,
-    {
-        Self(RoffNodeInner::IndentedParagraph {
-            content: content
-                .into_iter()
-                .map(|item| item.into_roff().into_inner())
-                .collect(),
-            indentation,
-            title: title.map(|t| t.roff()),
-        })
-    }
-
-    /// Creates a new paragraph node with a title.
-    pub fn tagged_paragraph<I, R>(content: I, title: impl Roffable) -> Self
-    where
-        I: IntoIterator<Item = R>,
-        R: IntoRoffNode,
-    {
-        Self(RoffNodeInner::TaggedParagraph {
-            content: content
-                .into_iter()
-                .map(|item| item.into_roff().into_inner())
-                .collect(),
-            title: title.roff(),
-        })
-    }
-
-    /// Creates a new example node. An example block usually has the font set to monospaced.
-    pub fn example<I, R>(content: I) -> Self
-    where
-        I: IntoIterator<Item = R>,
-        R: Roffable,
-    {
-        Self(RoffNodeInner::Example(
-            content.into_iter().map(|item| item.roff()).collect(),
-        ))
-    }
-
-    /// Creates a new synopsis node explaining the given `command` with `description` and `opts`.
-    pub fn synopsis<I, R, O>(command: impl Roffable, description: I, opts: O) -> Self
-    where
-        I: IntoIterator<Item = R>,
-        R: Roffable,
-        O: IntoIterator<Item = SynopsisOpt>,
-    {
-        Self(RoffNodeInner::Synopsis {
-            command: command.roff(),
-            text: description.into_iter().map(|item| item.roff()).collect(),
-            opts: opts.into_iter().collect(),
-        })
-    }
-
-    /// Creates a new URL node that will take the form of `[name](address)` where `name` is the
-    /// visible part of the URL and address is where it points to.
-    pub fn url(name: impl Roffable, address: impl Roffable) -> Self {
-        Self(RoffNodeInner::Url {
-            name: name.roff(),
-            address: address.roff(),
-        })
-    }
-
-    /// Creates a new email node that will where `address` is the email address and `name` is the
-    /// visible URL text. `address` may not be visible if the man page is being viewed as HTML.
-    pub fn email(name: impl Roffable, address: impl Roffable) -> Self {
-        Self(RoffNodeInner::Email {
-            name: name.roff(),
-            address: address.roff(),
-        })
-    }
-
-    /// Returns a node that will be rendered as a registered sign `®`.
-    pub fn registered_sign() -> Self {
-        Self(RoffNodeInner::RegisteredSign)
-    }
-
-    /// Returns a node that will be rendered as a left quote `“`.
-    pub fn left_quote() -> Self {
-        Self(RoffNodeInner::LeftQuote)
-    }
-
-    /// Returns a node that will be rendered as a right quote `”`.
-    pub fn right_quote() -> Self {
-        Self(RoffNodeInner::RightQuote)
-    }
-
-    /// Returns a node that will be rendered as a trademark sign `™`.
-    pub fn trademark_sign() -> Self {
-        Self(RoffNodeInner::TrademarkSign)
-    }
-
-    /// Nest nodes by indenting all of the nodes inside.
-    pub fn nested<I, R>(nodes: I) -> Self
-    where
-        I: IntoIterator<Item = R>,
-        R: IntoRoffNode,
-    {
-        Self(RoffNodeInner::Nested(
-            nodes.into_iter().map(R::into_roff).collect(),
-        ))
-    }
-
-    /// Breaks the line in text. Use this instead of adding raw `\n` characters to actually render
-    /// linebreaks.
-    pub fn linebreak() -> Self {
-        Self(RoffNodeInner::Break)
-    }
-}
-
 #[derive(Clone, Debug)]
 /// An option used by the [`RoffNode::synopsis`](RoffNode::synopsis) block.
 pub struct SynopsisOpt {
@@ -651,255 +400,12 @@ impl SynopsisOpt {
     }
 }
 
-#[derive(Clone, Debug)]
-/// Base struct used to create ROFFs.
-enum RoffNodeInner {
-    /// The most basic node type, contains only text with style.
-    Text(RoffText),
-    /// A simple paragraph that can contain nested items.
-    Paragraph(Vec<RoffNodeInner>),
-    /// Indented paragraph that can contain nested items. If no indentation is provided the default
-    /// is `4`.
-    IndentedParagraph {
-        content: Vec<RoffNodeInner>,
-        indentation: Option<u8>,
-        title: Option<RoffText>,
-    },
-    /// Paragraph with a title.
-    TaggedParagraph {
-        content: Vec<RoffNodeInner>,
-        title: RoffText,
-    },
-    /// An example block where text is monospaced.
-    Example(Vec<RoffText>),
-    Synopsis {
-        command: RoffText,
-        text: Vec<RoffText>,
-        opts: Vec<SynopsisOpt>,
-    },
-    Url {
-        name: RoffText,
-        address: RoffText,
-    },
-    Email {
-        name: RoffText,
-        address: RoffText,
-    },
-    RegisteredSign,
-    LeftQuote,
-    RightQuote,
-    TrademarkSign,
-    Nested(Vec<RoffNode>),
-    Break,
-}
-
-impl RoffNodeInner {
-    fn render<W: Write>(&self, writer: &mut W, mut was_text: bool) -> Result<bool, RoffError> {
-        match self {
-            RoffNodeInner::Text(text) => {
-                let styled = match text.style {
-                    FontStyle::Bold => {
-                        writer.write_all(BOLD)?;
-                        true
-                    }
-                    FontStyle::Italic => {
-                        writer.write_all(ITALIC)?;
-                        true
-                    }
-                    FontStyle::Roman => false,
-                };
-
-                writer.write_all(text.content.as_bytes())?;
-                if styled {
-                    writer.write_all(FONT_END)?;
-                }
-                was_text = true;
-            }
-            RoffNodeInner::Paragraph(content) => {
-                if was_text {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(PARAGRAPH)?;
-                writer.write_all(ENDL)?;
-                for node in content {
-                    was_text = node.render(writer, was_text)?;
-                }
-            }
-            RoffNodeInner::IndentedParagraph {
-                content,
-                indentation,
-                title,
-            } => {
-                if was_text {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(INDENTED_PARAGRAPH)?;
-                if let Some(indentation) = indentation {
-                    writer.write_all(SPACE)?;
-                    if let Some(title) = title {
-                        write_quoted_if_whitespace(title, writer)?;
-                    } else {
-                        writer.write_all(QUOTE)?;
-                        writer.write_all(QUOTE)?;
-                    }
-                    writer.write_all(SPACE)?;
-                    indentation.roff().render(writer)?;
-                }
-                writer.write_all(ENDL)?;
-                for node in content {
-                    was_text = node.render(writer, was_text)?;
-                }
-                writer.write_all(ENDL)?;
-                was_text = false;
-            }
-            RoffNodeInner::TaggedParagraph {
-                content,
-                title: tag,
-            } => {
-                if was_text {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(TAGGED_PARAGRAPH)?;
-                writer.write_all(ENDL)?;
-                tag.render(writer)?;
-                writer.write_all(ENDL)?;
-
-                for node in content {
-                    was_text = node.render(writer, was_text)?;
-                }
-                writer.write_all(ENDL)?;
-                was_text = false;
-            }
-            RoffNodeInner::Example(content) => {
-                if was_text {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(EXAMPLE_START)?;
-                writer.write_all(ENDL)?;
-                for node in content {
-                    node.render(writer)?;
-                }
-                writer.write_all(ENDL)?;
-                writer.write_all(EXAMPLE_END)?;
-                writer.write_all(ENDL)?;
-                was_text = false;
-            }
-            RoffNodeInner::Synopsis {
-                command,
-                text,
-                opts,
-            } => {
-                if was_text {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(SYNOPSIS_START)?;
-                writer.write_all(SPACE)?;
-                write_quoted_if_whitespace(command, writer)?;
-                writer.write_all(ENDL)?;
-                for elem in text {
-                    elem.render(writer)?;
-                }
-                if !text.is_empty() {
-                    writer.write_all(ENDL)?;
-                }
-                for op in opts {
-                    writer.write_all(ENDL)?;
-                    writer.write_all(SYNOPSIS_OPT)?;
-                    writer.write_all(SPACE)?;
-                    write_quoted_if_whitespace(&op.name, writer)?;
-                    if let Some(arg) = &op.argument {
-                        writer.write_all(SPACE)?;
-                        write_quoted_if_whitespace(arg, writer)?;
-                    }
-                    writer.write_all(ENDL)?;
-                    if let Some(description) = &op.description {
-                        for elem in description {
-                            elem.render(writer)?;
-                        }
-                    }
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(SYNOPSIS_END)?;
-                writer.write_all(ENDL)?;
-                was_text = false;
-            }
-            RoffNodeInner::Url { address, name } => {
-                if was_text {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(URL_START)?;
-                writer.write_all(SPACE)?;
-                address.render(writer)?;
-                writer.write_all(ENDL)?;
-                name.render(writer)?;
-                if !name.content.is_empty() {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(URL_END)?;
-                writer.write_all(ENDL)?;
-                was_text = false;
-            }
-            RoffNodeInner::Email { address, name } => {
-                if was_text {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(MAIL_START)?;
-                writer.write_all(SPACE)?;
-                address.render(writer)?;
-                writer.write_all(ENDL)?;
-                name.render(writer)?;
-                if !name.content.is_empty() {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(MAIL_END)?;
-                writer.write_all(ENDL)?;
-                was_text = false;
-            }
-            RoffNodeInner::RegisteredSign => writer.write_all(REGISTERED_SIGN)?,
-            RoffNodeInner::LeftQuote => writer.write_all(LEFT_QUOTE)?,
-            RoffNodeInner::RightQuote => writer.write_all(RIGHT_QUOTE)?,
-            RoffNodeInner::TrademarkSign => writer.write_all(TRADEMARK_SIGN)?,
-            RoffNodeInner::Nested(nodes) => {
-                if was_text {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(NESTED_START)?;
-                writer.write_all(ENDL)?;
-                was_text = false;
-                for node in nodes {
-                    was_text = node.inner_ref().render(writer, was_text)?;
-                }
-
-                if was_text {
-                    writer.write_all(ENDL)?;
-                }
-                writer.write_all(NESTED_END)?;
-                writer.write_all(ENDL)?;
-                was_text = false;
-            }
-            RoffNodeInner::Break => {
-                writer.write_all(ENDL)?;
-                writer.write_all(BREAK)?;
-                writer.write_all(ENDL)?;
-            }
-        }
-
-        Ok(was_text)
-    }
-}
-
 /// A trait that describes items that can be turned into a [`RoffNode`](RoffNode).
 pub trait IntoRoffNode {
     /// Convert this item into a `RoffNode`.
     fn into_roff(self) -> RoffNode;
 }
 
-impl IntoRoffNode for RoffNodeInner {
-    fn into_roff(self) -> RoffNode {
-        RoffNode(self)
-    }
-}
-
 impl IntoRoffNode for RoffNode {
     fn into_roff(self) -> RoffNode {
         self
@@ -948,12 +454,6 @@ impl Roffable for std::borrow::Cow<'_, str> {
     }
 }
 
-impl Roffable for RoffText {
-    fn roff(&self) -> RoffText {
-        self.clone()
-    }
-}
-
 impl Roffable for u8 {
     fn roff(&self) -> RoffText {
         RoffText::new(self.to_string(), None)
@@ -1023,7 +523,7 @@ mod tests {
 this is some very \fBspecial\fR text
 .SH "test section 2"
 .IP "" 4
-\fILorem ipsum\fR dolor sit amet, consectetur adipiscing elit\. Vivamus quis malesuada eros\.
+\fILorem ipsum\fR dolor sit amet, consectetur adipiscing elit. Vivamus quis malesuada eros.
 .SH "test section 3"
 .TP
 \fBparagraph title\fR
@@ -1065,9 +565,9 @@ Another indented paragraph
             rendered,
             r#".TH test 1
 .SH "BASE SECTION"
-.SS "with some subtitle\.\.\."
+.SS "with some subtitle..."
 .P
-some text in first paragraph\.
+some text in first paragraph.
 .RS
 .P
 some nested paragraph
@@ -1102,12 +602,12 @@ back two levels left without roffs"#,
         assert_eq!(
             r#".TH test\-examples 3
 .SH "BASE SECTION"
-Lorem ipsum dolor sit amet, consectetur adipiscing elit\. Vivamus quis malesuada eros\.
+Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus quis malesuada eros.
 .EX
 let example = String::new()
-let x = example\.clone();
-if x\.len() > 0 {
-	println!("{}", x);
+let x = example.clone();
+if x.len() > 0 {
+	println!(\(dq{}\(dq, x);
 }
 
 .EE
@@ -1116,18 +616,6 @@ if x\.len() > 0 {
         )
     }
 
-    #[test]
-    fn it_escapes() {
-        let input = "This-is-some-text
-Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus quis malesuada eros.";
-
-        assert_eq!(
-            escape(input),
-            "This\\-is\\-some\\-text
-Lorem ipsum dolor sit amet, consectetur adipiscing elit\\. Vivamus quis malesuada eros\\.",
-        )
-    }
-
     #[test]
     fn synopsis_works() {
         let roff = Roff::new("test-synopsis", SectionNumber::Miscellaneous).section(
@@ -1148,7 +636,7 @@ Lorem ipsum dolor sit amet, consectetur adipiscing elit\\. Vivamus quis malesuad
             r#".TH test\-synopsis 7
 .SH SYNOPSIS
 .SY ls
-lists files in the given\fIpath\fR\.
+lists files in the given\fIpath\fR.
 
 .OP \-l
 use a long listing format
@@ -1184,23 +672,23 @@ with \-l, scale sizes by SIZE when printing them
         assert_eq!(
             r#".TH test\-urls 7
 .SH URLS
-.UR https://github\.com/vv9k/roffman
+.UR https://github.com/vv9k/roffman
 GitHub
 .UE
-.UR https://crates\.io/crates/roffman
-crates\.io
+.UR https://crates.io/crates/roffman
+crates.io
 .UE
-.UR https://docs\.rs/roffman
-docs\.rs
+.UR https://docs.rs/roffman
+docs.rs
 .UE
-.UR https://docs\.rs/roffman
+.UR https://docs.rs/roffman
 .UE
 .UR 
 .UE
-.MT test@invalid\.domain
+.MT test@invalid.domain
 John Test
 .ME
-.MT test@invalid\.domain
+.MT test@invalid.domain
 .ME
 .MT 
 .ME
@@ -1221,15 +709,48 @@ John Test
                 RoffNode::registered_sign(),
                 RoffNode::text(" roffman"),
                 RoffNode::trademark_sign(),
+                RoffNode::linebreak(),
+                RoffNode::text("123"),
+                RoffNode::en_dash(),
+                RoffNode::text("321"),
+                RoffNode::linebreak(),
+                RoffNode::text("some text"),
+                RoffNode::em_dash(),
+                RoffNode::text("interupted sentence in the middle"),
+                RoffNode::em_dash(),
+                RoffNode::text("more text..."),
+                RoffNode::linebreak(),
+                RoffNode::text("64"),
+                RoffNode::non_breaking_space(),
+                RoffNode::text("KiB"),
+                RoffNode::linebreak(),
+                RoffNode::en_dash(),
+                RoffNode::paragraph(["paragraph after special sequence"]),
+                RoffNode::comment("that was interesting indeed..."),
+                RoffNode::comment("this should span\nover multiple\nlines correctly."),
             ],
         );
 
         let rendered = roff.to_string().unwrap();
         assert_eq!(
+            rendered,
             r#".TH test\-strings 7
 .SH STRINGS
-\*(lqthis is some example quoted text\.\*(rq \*R roffman\*(Tm"#,
-            rendered
+\(lqthis is some example quoted text.\(rq \(rg roffman\(tm
+.br
+123\(en321
+.br
+some text\(eminterupted sentence in the middle\(emmore text...
+.br
+64\~KiB
+.br
+\(en
+.P
+paragraph after special sequence\"that was interesting indeed...
+\"this should span
+\"over multiple
+\"lines correctly.
+"#
         )
     }
 
@@ -1251,13 +772,13 @@ John Test
         assert_eq!(
             r#".TH test\-sections 7
 .SH TEXTS
-this is some example text\.
+this is some example text.
 .SH NEXT
-this is some example text on second section\.
-this is some example\.
-this is some example text\.
+this is some example text on second section.
+this is some example.
+this is some example text.
 .SH THIRD
-this is some example text\."#,
+this is some example text."#,
             rendered
         )
     }
@@ -1280,11 +801,11 @@ this is some example text\."#,
             rendered,
             r#".TH test\-breaks 7
 .SH BREAKS
-this is some example text\.
+this is some example text.
 .br
-this is some example text on second line\.
+this is some example text on second line.
 .br
-this is some example text on third line\."#
+this is some example text on third line."#
         )
     }
 }
